'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var _class = function () {
  function _class(adapter, config, logger) {
    _classCallCheck(this, _class);

    this.dbLocation = _path2.default.join(config.workDir, 'db');
    try {
      this.storageInit();
    } catch (err) {
      logger.error("Failed to initialize auth-structure in " + this.dbLocation);
    }
    this.initTokenDB();
    this.settings = config.auth;
    this.adapter = adapter;
  }

  _createClass(_class, [{
    key: 'storageInit',
    value: function storageInit() {
      var userTokens = _path2.default.join(this.dbLocation, 'user_tokens.json');

      if (!_fsExtra2.default.ensureDirSync(this.dbLocation)) {
        _fsExtra2.default.mkdirsSync(this.dbLocation);
      }

      if (!_fsExtra2.default.ensureFileSync(userTokens)) {
        _fsExtra2.default.outputJsonSync(userTokens, {});
      }
    }
  }, {
    key: 'userLogin',
    value: function userLogin(username, password, email) {
      return this.adapter.userLogin(username, password, email);
    }
  }, {
    key: 'userAdd',
    value: function userAdd(username, password, email) {
      return this.adapter.userAdd(username, password, email);
    }
  }, {
    key: 'userRemove',
    value: function userRemove(username, password) {
      return this.adapter.userRemove(username, password);
    }
  }, {
    key: 'userLogout',
    value: function userLogout(token) {
      var _this = this;

      var user_tokens_path = _path2.default.join(this.dbLocation, 'user_tokens.json');
      var allTokens = void 0;

      return new Promise(function (resolve) {
        try {
          var tokenString = _fs2.default.readFileSync(user_tokens_path, 'utf8');
          allTokens = JSON.parse(tokenString);
          delete allTokens[token];
        } catch (e) {
          allTokens = {};
        }

        _fs2.default.writeFileSync(user_tokens_path, JSON.stringify(allTokens, null, 2), { 'mode': '0777' });
        _this.updateTokenDB();
        resolve();
      });
    }
  }, {
    key: 'shouldBeAbleTo',
    value: function shouldBeAbleTo(accessType, packageName, accessToken) {
      var _this2 = this;

      return new Promise(function (resolve, reject) {
        if (_this2.settings.public === true) {
          resolve();
        }

        if (accessToken) {
          accessToken = accessToken.substr(7);
        }

        if (accessType === 'access') {
          if (_this2.settings.users.canAccess) {
            var user = _this2.verifyToken(accessToken);
            if (user) {
              resolve();
            } else {
              reject("Invalid user");
            }
          } else {
            reject("Users are not allowed access");
          }
        } else if (accessType === 'publish') {
          if (_this2.settings.users.canPublish) {
            var _user = _this2.verifyToken(accessToken);
            if (_user) {
              resolve();
            } else {
              reject("Invalid user");
            }
          } else {
            reject("Users are not allowed to publish");
          }
        }

        reject();
      });
    }
  }, {
    key: 'verifyLogin',
    value: function verifyLogin(username, password) {
      return this.adapter.userLogin(username, password);
    }
  }, {
    key: 'verifyToken',
    value: function verifyToken(token) {
      if (typeof this.tokens[token] === 'string') {
        return this.tokens[token];
      } else {
        return false;
      }
    }
  }, {
    key: 'updateTokenDB',
    value: function updateTokenDB() {
      var tokenLocation = _path2.default.join(this.dbLocation, 'user_tokens.json');
      _fs2.default.writeFileSync(tokenLocation, JSON.stringify(this.tokens, null, 2), { 'mode': '0777' });
    }
  }, {
    key: 'addTokenToDB',
    value: function addTokenToDB(username, token) {
      var tokenLocation = _path2.default.join(this.dbLocation, 'user_tokens.json');
      var tokens = void 0;

      if (_fs2.default.existsSync(tokenLocation)) {
        var jsonString = _fs2.default.readFileSync(tokenLocation);
        tokens = JSON.parse(jsonString);
      } else {
        tokens = {};
      }

      tokens[token] = username;
      _fs2.default.writeFileSync(tokenLocation, JSON.stringify(tokens, null, 2), { 'mode': '0777' });
      this.initTokenDB();
    }
  }, {
    key: 'initTokenDB',
    value: function initTokenDB() {
      var user_token_path = _path2.default.join(this.dbLocation, 'user_tokens.json');
      try {
        var user_tokens_json = _fs2.default.readFileSync(user_token_path, 'utf8');
        this.tokens = JSON.parse(user_tokens_json);
      } catch (e) {
        this.tokens = {};
      }
    }
  }]);

  return _class;
}();

exports.default = _class;