'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _jsSha = require('js-sha256');

var _jsSha2 = _interopRequireDefault(_jsSha);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/*
 * This file serves as a way to implement an authentication server.
 * The current implementation serves as a simple example of local authentication.
 * ap-npm was created to be easily extensible (which alternatives weren't).
 * We promote implementing a proper authentication method.
 */
var _class = function () {
  function _class(config) {
    _classCallCheck(this, _class);

    this.dbLocation = _path2.default.join(config.workDir, 'db');
    this.initUserDB();
    this.settings = config.auth;
  }

  _createClass(_class, [{
    key: 'userLogin',
    value: function userLogin(username, password) {
      var _this = this;

      var email = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'admin';

      return new Promise(function (resolve) {
        var userLoggedIn = void 0;
        try {
          userLoggedIn = _this.users[username].password === _jsSha2.default.sha256(password);

          if (userLoggedIn) {
            resolve(userLoggedIn);
          }
        } catch (err) {
          resolve(false);
        }
      }).catch(function () {
        return false;
      });
    }
  }, {
    key: 'userAdd',
    value: function userAdd(username, password, email) {
      var _this2 = this;

      return new Promise(function (resolve) {
        if (_this2.settings.register) {
          if (_typeof(_this2.users[username]) === "object") {
            resolve(false);
          } else {
            _this2.users[username] = {
              username: username,
              password: _jsSha2.default.sha256(password),
              email: email
            };
            _this2.updateUserDB();
            _this2.initUserDB();

            resolve(true);
          }
        } else {
          resolve(false);
        }
      }).catch(function () {
        return false;
      });
    }

    /*
     * Doesn't get used yet, npm doesn't implement it and neither have we (yet)
     */

  }, {
    key: 'userRemove',
    value: function userRemove(username, password) {
      var _this3 = this;

      return new Promise(function (resolve, reject) {
        if (_this3.settings.remove) {
          if (_this3.users[username] && _this3.users[username][password] === _jsSha2.default.sha256(password)) {
            _this3.users.remove(username);
            _this3.updateUserDB();

            // Success
            resolve(true);
          }
        } else {
          reject("Not allowed to remove users");
        }
      }).catch(function () {
        return false;
      });
    }

    // Just here for local auth

  }, {
    key: 'initUserDB',
    value: function initUserDB() {
      var user_db_path = _path2.default.join(this.dbLocation, 'user_db.json');
      try {
        var user_db_json = _fs2.default.readFileSync(user_db_path, 'utf8');
        this.users = JSON.parse(user_db_json);
      } catch (err) {
        this.users = {};
      }
    }

    // Just here for local auth

  }, {
    key: 'updateUserDB',
    value: function updateUserDB() {
      var user_db_path = _path2.default.join(this.dbLocation, 'user_db.json');
      _fs2.default.writeFileSync(user_db_path, JSON.stringify(this.users, null, 2), { 'mode': '0777' });
      this.initUserDB();
    }
  }]);

  return _class;
}();

exports.default = _class;