'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (container) {
  container.set('remote-registry', function () {
    var Route = require('../routes/auth-user-add').default;
    return new Route();
  });

  container.set('express', function () {
    var express = require('express');
    var routes = require('../routes').default;
    var app = express();
    app.set('env', process.env.NODE_ENV || 'production');
    routes(app, container);
    return app;
  });

  container.set('validator', function () {
    var PackageValidator = require('../util/validator').default;
    return new PackageValidator(container.get('storage'));
  });

  container.set('auth', function () {
    var Auth = require('../auth/index').default;
    return new Auth(container.get('auth-adapter'), container.get('config'), container.get('logger'));
  });

  container.set('auth-adapter', function () {
    var AuthAdapter = void 0;
    if (container.get('config').auth.adapter === '/auth/json-db') {
      AuthAdapter = require(_path2.default.join(__dirname, '..', container.get('config').auth.adapter)).default;
    } else {
      AuthAdapter = require(container.get('config').auth.adapter).default;
    }
    return new AuthAdapter(container.get('config'));
  });

  container.set('proxy', function () {
    var Util = require('../util/package-proxy').default;
    return new Util(container.get('config').proxyUrl);
  });
};

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }